@@ -12,14 +12,14 @@ rownames(trajMat) = traj[,1]
 
 test_that('default', {
   suppressWarnings({
-    model = latrend(lcMethodAKMedoids(response = 'Value'), trajMat)
+    model = latrend(lcMethodAkmedoids(response = 'Value'), trajMat)
   })
   expect_valid_lcModel(model)
 })
 
 test_that('many clusters', {
   suppressWarnings({
-    model = latrend(lcMethodAKMedoids(response = 'Value', nClusters=10), trajMat)
+    model = latrend(lcMethodAkmedoids(response = 'Value', nClusters=10), trajMat)
   })
   expect_valid_lcModel(model)
 })
